.. pycraf-geometry:

**************************************
Geometry helpers (`pycraf.geometry`)
**************************************

.. currentmodule:: pycraf.geometry

Introduction
============

The `~pycraf.geometry` sub-package just offers some convenience functions
for various geometrical calculations, e.g., in spherical coordinates.


See Also
========

- `Astropy Units and Quantities package <http://docs.astropy.org/en/stable/
  units/index.html>`_, which is used extensively in pycraf.
- `Spherical coordinates <https://en.wikipedia.org/wiki/Spherical_coordinate_system>`_

Reference/API
=============

.. automodapi:: pycraf.geometry
    :no-inheritance-diagram:
